Install the latest
===================

To install the latest version of ml_scheduler simply run:

`pip3 install ml_scheduler`

OR

`poetry add ml_scheduler`

OR

`pipenv install ml_scheduler`


Changelog
=========
## 1.0.0 - TBD
- Initial API stable release.
